a connection object of class "textConnection" containing the markdown document
limitations
A character vector containing the given limitations
emptyIfNULL
switch which decides whether limitations section should be ignored, if
limitations input is NULL or if it should state that there are no known limitations.