helper function which creates a section consisting of header and content in a markdown document and skips section when content is empty
.section(data, zz, title, level, id = NULL)a character vector to be written to the markdown document
a connection object of class "textConnection" containing the markdown document
the title to be used (character vector of length 1)
level of the heading (1 means main header, higher numbers reflect lower levels)
ID given to the title (relevant for anchors)
Falk Benke
goxygen, createModulePage