Learn R Programming

goxygen (version 1.0.3)

.updateImagePaths: .updateImagePaths

Description

helper function which updates relative image paths so that they refer to a subfolder images instead of refering to the current folder.

Usage

.updateImagePaths(x)

Arguments

x

A character vector containing image paths.

Author

Jan Philipp Dietrich

See Also

goxygen, createModulePage