buildMarkdown: buildMarkdown
Description
Creates a folder filled with markdown files from a list object with markdown code
Usage
buildMarkdown(x, folder = "markdown")
Arguments
- x
a named list of markdown codes which should be written as markdown files.
The name of each entry will become the file name.
- folder
folder the markdown files should be written to
Author
Jan Philipp Dietrich