helper function which includes interface plot figures in a markdown document, if available.
The figures need to be created beforehand.
Usage
.interfaceplot(zz, name, docfolder)
Arguments
- zz
a connection object of class "textConnection" containing the markdown document
- name
Name of the module for which the interfaceplot should be shown
- docfolder
folder the documentation should be written to relative to model folder
Author
Jan Philipp Dietrich