Skip to content

helper function which updates relative image paths so that they refer to a subfolder images instead of refering to the current folder.

Usage

.updateImagePaths(x)

Arguments

x

A character vector containing image paths.

Author

Jan Philipp Dietrich