helper function which writes a character vector line by line in a markdown document
Arguments
- zz
a connection object of class "textConnection" containing the markdown document
- data
a character vector to be written to the markdown document
Author
Jan Philipp Dietrich