powered by
helper function which writes a character vector line by line in a markdown document
.write(zz, data)
a connection object of class "textConnection" containing the markdown document
a character vector to be written to the markdown document
Jan Philipp Dietrich
goxygen, createModulePage
goxygen
createModulePage