check_pandoc: check_pandoc
Description
Support function which checks pandoc availability and stops with an error in case
that pandoc cannot be found
Usage
check_pandoc(error = FALSE)
Value
boolean indicating whether pandoc is available or not.
Arguments
- error
boolean indicating whether function should throw an error in case of missing pandoc or return a boolean FALSE.
Author
Jan Philipp Dietrich