Creates markdown code from a supplied data list
Arguments
- data
a list of data entries for the resulting markdown page. Following
entries can be provided:
- title
Page title
- description
General description
- citation
A read in citation in Citation File Format (CFF)
Value
a character vector containing the produced markdown text
Author
Jan Philipp Dietrich