R/helper_functions.R
dot-updateImagePaths.Rd
helper function which updates relative image paths so that they refer to a subfolder images instead of refering to the current folder.
.updateImagePaths(x)
A character vector containing image paths.
goxygen, createModulePage
goxygen
createModulePage
Jan Philipp Dietrich